#' get pAttribute
#'
#' @param pAttribute the pAttribute to get
#' @exportMethod pAttribute
#' @rdname pAttribute-method
setGeneric("pAttribute", function(object) standardGeneric("pAttribute"))

#' @exportMethod name
#' @rdname polmineR-generics
setGeneric("name", function(x) standardGeneric("name"))

#' @exportMethod name<-
#' @rdname polmineR-generics
setGeneric("name<-", function(x, value) standardGeneric("name<-"))


